Documentation for RCK is comprised of several documents. 
Information addresses the basic concepts, provides some examples, and covers usage of tools in the RCK distribution. 

### Contents: 
* [Adjacencies](Adjacencies.md)
* [Adjacencies Groups](AdjacencyGroups.md)
* [Segments](Segments.md)
* [Installation](Installation.md)
* [Usage](Usage.md)